@@ -7,14 +7,13 @@ from datetime import datetime
 from cStringIO import StringIO
 from ConfigParser import ConfigParser
 from itertools import islice
-import tarfile
 from shutil import rmtree
-from zipfile import ZipFile, ZIP_DEFLATED
 
 import tg
 from pylons import app_globals as g
 os.environ['HGRCPATH'] = '' # disable loading .hgrc
 from mercurial import ui, hg, cmdutil, commands
+from mercurial.error import RepoLookupError
 
 from pymongo.errors import DuplicateKeyError
 
@@ -24,7 +23,7 @@ from ming.utils import LazyProperty
 
 from allura import model as M
 from allura.lib import helpers as h
-from allura.model.repository import topological_sort, GitLikeTree
+from allura.model.repository import topological_sort, GitLikeTree, zipdir
 
 log = logging.getLogger(__name__)
 
@@ -291,7 +290,10 @@ class HgImplementation(M.RepositoryImplementation):
 
     def symbolics_for_commit(self, commit):
         branch_heads, tags = super(self.__class__, self).symbolics_for_commit(commit)
-        ctx = self._hg[commit._id]
+        try:
+            ctx = self._hg[commit._id]
+        except RepoLookupError as e:
+            return [], tags
         return [ctx.branch()], tags
 
     def compute_tree_new(self, commit, tree_path='/'):
@@ -338,21 +340,10 @@ class HgImplementation(M.RepositoryImplementation):
         tmpfilename = os.path.join(self._repo.tarball_path, '%s%s' % (archive_name, '.tmp'))
         if os.path.exists(path):
             rmtree(path)
-
         try:
-            commands.archive(
-                HgUI(),
-                self._hg,
-                path,
-                rev=commit,
-                prefix='')
-            with ZipFile(tmpfilename, 'w') as tarball_zip:
-                for root, dirs, files in os.walk(path):
-                    for name in files:
-                        if name != '.hg_archival.txt':
-                            file_to_zip = os.path.join(root, name)
-                            arcname = file_to_zip[len(os.path.dirname(path)):].strip('/')
-                            tarball_zip.write(file_to_zip, arcname, compress_type=ZIP_DEFLATED)
+            commands.archive(HgUI(), self._hg, path, rev=commit, prefix='')
+            basedir = os.path.basename(path)
+            zipdir(path, tmpfilename, exclude=basedir + '/.hg_archival.txt')
             os.rename(tmpfilename, filename)
         finally:
             rmtree(path)
